HdAddressGenerator class abstract
Constructors
- HdAddressGenerator()
-
const
Properties
- addressPrefix → AddressPrefix
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- mainAddress → Address
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addressAtIndex(
{required int typeIndex, required int index}) → Future< Address> -
changeAddressAtIndex(
int index) → Future< Address> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
receiveAddressAtIndex(
int index) → Future< Address> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited