LegacyAddressGenerator class
- Inheritance
-
- Object
- HdAddressGenerator
- LegacyAddressGenerator
Constructors
- LegacyAddressGenerator({required LegacyPubKeyCallback pubKeyCallback, required Address mainAddress})
Properties
- addressPrefix → AddressPrefix
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- mainAddress → Address
-
final
- pubKeyCallback → LegacyPubKeyCallback
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addressAtIndex(
{required int typeIndex, required int index}) → Future< Address> -
override
-
changeAddressAtIndex(
int index) → Future< Address> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
receiveAddressAtIndex(
int index) → Future< Address> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited