SchnorrAddressGenerator class

Inheritance

Constructors

SchnorrAddressGenerator({required String hdPublicKey, required AddressPrefix addressPrefix})

Properties

addressPrefix AddressPrefix
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
mainAddress Address
latefinaloverride-getter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wallet HdWalletView
latefinal

Methods

addressAtIndex({required int typeIndex, required int index}) Future<Address>
override
changeAddressAtIndex(int index) Future<Address>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
receiveAddressAtIndex(int index) Future<Address>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited