KaspaClient class

Implementers

Constructors

KaspaClient({required ClientChannel channel})
KaspaClient.url(String url, {bool isSecure = false})
factory

Properties

channel ↔ ClientChannel
latefinal
hashCode int
The hash code for this object.
no setterinherited
rpcClient RPCClient
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
getBalancesByAddresses(Iterable<String> addresses) Future<List<BalancesByAddressEntry>>
getBlockByHash(String hash, {bool includeTransactions = true}) Future<RpcBlock>
getInfo() Future<GetInfoResponseMessage>
getMempoolEntries({bool includeOrphanPool = true, bool filterTransactionPool = true}) Future<List<MempoolEntry>>
getMempoolEntriesByAddresses(Iterable<String> addresses, {bool filterTransactionPool = true, bool includeOrphanPool = true}) Future<List<MempoolEntryByAddress>>
getMempoolEntry({required String txId, bool includeOrphanPool = true, bool filterTransactionPool = true}) Future<MempoolEntry>
getNetworkName() Future<String>
getUtxosByAddresses(Iterable<String> addresses) Future<List<UtxosByAddressesEntry>>
getVirtualSelectedParentBlueScore() Future<Int64>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyBlockAdded() Stream<BlockAddedNotificationMessage>
notifyUtxosChanged(Iterable<String> addresses) Stream<UtxosChangedNotificationMessage>
notifyVirtualDaaScoreChanged() Stream<Int64>
notifyVirtualSelectedParentBlueScoreChanged() Stream<Int64>
notifyVirtualSelectedParentChainChanged({required dynamic includeAcceptedTransactionIds}) Stream<VirtualSelectedParentChainChangedNotificationMessage>
stopNotifyingUtxosChanged(List<String> addresses) Future<void>
submitTransaction(RpcTransaction transaction, {bool allowOrphan = false}) Future<String>
terminate() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited