createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
BalancesByAddressEntry createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
BalancesByAddressEntry createEmptyInstance() => create();