createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
BlockAddedNotificationMessage createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
BlockAddedNotificationMessage createEmptyInstance() => create();