createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
GetInfoResponseMessage createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
GetInfoResponseMessage createEmptyInstance() => create();