createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
MempoolEntryByAddress createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
MempoolEntryByAddress createEmptyInstance() => create();