createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
RPCError createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
RPCError createEmptyInstance() => create();