createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
RpcBlockLevelParents createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
RpcBlockLevelParents createEmptyInstance() => create();