copyWith method

  1. @Deprecated('Using this can add significant overhead to your binary. ' 'Use [GeneratedMessageGenericExtensions.rebuild] instead. ' 'Will be removed in next major version')
RpcOutpoint copyWith(
  1. void updates(
    1. RpcOutpoint
    )
)
override

Apply updates to a copy of this message.

Makes a writable shallow copy of this message, applies the updates to it, and marks the copy read-only before returning it.

Implementation

@$core.Deprecated('Using this can add significant overhead to your binary. '
    'Use [GeneratedMessageGenericExtensions.rebuild] instead. '
    'Will be removed in next major version')
RpcOutpoint copyWith(void Function(RpcOutpoint) updates) =>
    super.copyWith((message) => updates(message as RpcOutpoint))
        as RpcOutpoint;