createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
RpcTransactionInputVerboseData createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
RpcTransactionInputVerboseData createEmptyInstance() => create();