createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
RpcTransactionVerboseData createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
RpcTransactionVerboseData createEmptyInstance() => create();