createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
RpcUtxoEntry createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
RpcUtxoEntry createEmptyInstance() => create();