createEmptyInstance method
Creates an empty instance of the same message type as this.
Implementation
UtxosChangedNotificationMessage createEmptyInstance() => create();
Creates an empty instance of the same message type as this.
UtxosChangedNotificationMessage createEmptyInstance() => create();