TxOutput class

Annotations
  • @freezed

Constructors

TxOutput({required Int64 value, required ScriptPublicKey scriptPublicKey})
const
factory

Properties

copyWith → $TxOutputCopyWith<TxOutput>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scriptPublicKey ScriptPublicKey
no setterinherited
value → Int64
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRpc() RpcTransactionOutput
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited