UtxoEntry class

Annotations
  • @Freezed.new(equal: false)

Constructors

UtxoEntry({required BigInt amount, required ScriptPublicKey scriptPublicKey, required BigInt blockDaaScore, required bool isCoinbase})
const
factory
UtxoEntry.fromJson(Map<String, dynamic> json)
factory
UtxoEntry.fromRpc(RpcUtxoEntry rpc)
factory

Properties

amount BigInt
no setterinherited
blockDaaScore BigInt
no setterinherited
copyWith → $UtxoEntryCopyWith<UtxoEntry>
no setterinherited
hashCode int
The hash code for this object.
no setteroverride
isCoinbase bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scriptPublicKey ScriptPublicKey
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toRpc() RpcUtxoEntry
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override