HdWallet class abstract

Implemented types
Implementers

Constructors

HdWallet.forSeed(Uint8List seed, {required HdWalletType type})
factory
HdWallet.forSeedHex(String seed, {required HdWalletType type})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type HdWalletType
no setter

Methods

deriveKeyPair({required int typeIndex, required int index}) KeyPair
derivePublicKey({required int typeIndex, required int index}) Uint8List
override
getExtendedPrivateKey(String seed) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

hdPublicKeyFromSeed(Uint8List seed, {required NetworkType networkType}) String