HdWalletLegacy class

Inheritance

Constructors

HdWalletLegacy(Uint8List seed)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type HdWalletType
no setteroverride

Methods

deriveKeyPair({required int typeIndex, required int index}) KeyPair
override
derivePublicKey({required int typeIndex, required int index}) Uint8List
inherited
getExtendedPrivateKey(String seed) String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited