WalletService class

Constructors

WalletService({required SignerBase signer, required KaspaClient client})
const

Properties

client KaspaClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signer SignerBase
final

Methods

createCompoundTx({required Address compoundAddress, required List<Utxo> spendableUtxos, required BigInt feePerInput}) SendTx
createSendTx({required Address toAddress, required BigInt amountRaw, required List<Utxo> spendableUtxos, required BigInt feePerInput, String? note}) SendTx
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendTransaction(SendTx rawTx, {required Address changeAddress}) Future<SendResult>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited