Outpoint class
- Annotations
-
- @freezed
Constructors
- Outpoint({required String transactionId, required int index})
-
factory
-
Outpoint.fromJson(Map<
String, dynamic> json) -
factory
- Outpoint.fromRpc(RpcOutpoint rpc)
-
factory
Properties
-
copyWith
→ $OutpointCopyWith<
Outpoint> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transactionId → String
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toRpc(
) → RpcOutpoint -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited